import { EventEmitter, IEventMap } from './internal/events';
import { IServices, IServiceClient } from 'json-talk';
declare type Engine = 'winrt' | 'trident';
export interface WebViewEvents extends IEventMap {
    'did-finish-load': [];
    'page-title-updated': [string];
}
export interface WebPreferences {
    engine: Engine | null;
}
export declare class WebView<Services extends IServices = any> extends EventEmitter<WebViewEvents> {
    #private;
    constructor(callbacks: {
        onPageTitleUpdated: (title: string) => void;
        onReadyToShow: () => void;
    }, preferences: WebPreferences);
    publishServices(services: IServices): void;
    getService<ServiceName extends (keyof Services & string)>(serviceName: ServiceName): IServiceClient<Services[ServiceName]>;
    get id(): number;
    get engine(): Engine | null;
    isDestroyed(): boolean;
    loadFile(filePath: string): void;
    loadURL(url: string): void;
    setDevToolsEnabled(enabled: boolean): void;
    isDevToolsEnabled(): boolean;
    reload(): void;
}
export declare const WebViews: {
    getAllWebViews(): WebView<any>[];
    /**
     * Alias to [[getAllWebViews]]
     */
    getAllWebContents(): WebView<any>[];
    /**
     * Alias to [[getFocusedWebView]]
     */
    getFocusedWebContents(): WebView<any> | null;
    getFocusedWebView(): WebView<any> | null;
    fromId(id: number): WebView<any> | null;
    setDefaultEngine(engine: Engine): void;
    getDefaultEngine(): "winrt" | "trident" | null;
    isEngineAvailable(engine: Engine): boolean;
};
export {};
